@@ -83,7 +83,7 @@ class Feeds(object):
             star           INTEGER)
         """)
 
-        # Purged entries table
+        # Purged entries table -- blacklist for new entries
         self.cursor.execute("""
         CREATE TABLE IF NOT EXISTS purged (
             id           INTEGER PRIMARY KEY AUTOINCREMENT,
@@ -187,6 +187,13 @@ class Feeds(object):
             entries_purged += self.purge_feed(feed["id"], num_entries_to_keep, keep_unviewed=keep_unviewed)
         return entries_purged
 
+    def unblacklist_purged_entries(self):
+        self.cursor.execute("DELETE FROM purged")
+        self.database.isolation_level = None
+        self.cursor.execute("VACUUM")
+        self.database.isolation_level = ''
+        self.database.commit()
+
     def add_feed(self, url: str, category: str, feed_name: str = "") -> Optional[int]:
         url = parse_url(url)
         if url == "":
@@ -242,10 +249,10 @@ class Feeds(object):
         self.cursor.execute(
             """
             INSERT INTO feeds 
-                (author, category, type, url, channel_url, added_on, refreshed_on) 
+                (author, category, type, url, channel_url, added_on, refreshed_on, purge_excluded) 
             VALUES
                 (:author, :category, :type, :url, :channel_url, datetime('now', 'localtime'),
-                 datetime('now', 'localtime'));
+                 datetime('now', 'localtime'), :purge_excluded);
             """,
             parsed_feed
         )
