@@ -5,7 +5,6 @@ import os
 import sys
 import tempfile
 from typing import Optional
-import webbrowser
 
 from PyQt6 import QtWidgets, QtGui, QtCore, QtNetwork
 
@@ -176,8 +175,8 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow, QtCore.QCoreApplication):
             self.tasks_thread.set_schedule()
 
     def update_proxies(self):
-        for feed_type in self.entry_widgets:
-            self.entry_widgets[feed_type].download.update_proxy()
+        for entry_widget in self.entry_widgets.values():
+            entry_widget.download.update_proxy()
         self.feeds.downloader.update_proxy()
 
     def search_text_changed_callback(self, text):
@@ -388,13 +387,6 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow, QtCore.QCoreApplication):
             if not self.table_entries.isRowHidden(current_row):
                 self.table_entries.selectRow(current_row)
                 return
-                
-
-    def open_database_callback(self):
-        webbrowser.open(self.feeds.database.dir)
-
-    def open_log_callback(self):
-        webbrowser.open(logger.root.handlers[0].baseFilename)
 
     def change_category_name(self, current_name: str):
         dialog = RenameCategoryDialog(self, current_name)
